@@ -109,6 +109,13 @@ class TestMetafunc:
             metafunc.parametrize(("x","y"), [("abc", "def"),
                                              ("ghi", "jkl")], ids=["one"]))
 
+    @pytest.mark.issue510
+    def test_parametrize_empty_list(self):
+        def func( y): pass
+        metafunc = self.Metafunc(func)
+        metafunc.parametrize("y", [])
+        assert 'skip' in metafunc._calls[0].keywords
+
     def test_parametrize_with_userobjects(self):
         def func(x, y): pass
         metafunc = self.Metafunc(func)
@@ -170,6 +177,11 @@ class TestMetafunc:
         result = idmaker((py.builtin._totext("a"), "b"), [({}, b'\xc3\xb4')])
         assert result == ['a0-\\xc3\\xb4']
 
+    def test_idmaker_with_bytes_regex(self):
+        from _pytest.python import idmaker
+        result = idmaker(("a"), [(re.compile(b'foo'), 1.0)])
+        assert result == ["foo"]
+
     def test_idmaker_native_strings(self):
         from _pytest.python import idmaker
         totext = py.builtin._totext
