@@ -2,15 +2,17 @@
 terminal reporting of the full testing process.
 """
 import collections
-import pytest
-import py
 import sys
 
+import _pytest._pluggy as pluggy
+import _pytest._code
+import py
+import pytest
+from _pytest import runner
 from _pytest.main import EXIT_NOTESTSCOLLECTED
 from _pytest.terminal import TerminalReporter, repr_pythonversion, getreportopt
 from _pytest.terminal import build_summary_stats_line, _plugin_nameversions
-from _pytest import runner
-import _pytest._pluggy as pluggy
+
 
 def basic_run_report(item):
     runner.call_and_report(item, "setup", log=False)
@@ -153,7 +155,7 @@ class TestTerminal:
 
     def test_itemreport_directclasses_not_shown_as_subclasses(self, testdir):
         a = testdir.mkpydir("a123")
-        a.join("test_hello123.py").write(py.code.Source("""
+        a.join("test_hello123.py").write(_pytest._code.Source("""
             class TestClass:
                 def test_method(self):
                     pass
@@ -186,6 +188,10 @@ class TestTerminal:
             result.stdout.fnmatch_lines([
                 "*raise KeyboardInterrupt   # simulating the user*",
             ])
+        else:
+            result.stdout.fnmatch_lines([
+                "to show a full traceback on KeyboardInterrupt use --fulltrace"
+            ])
         result.stdout.fnmatch_lines(['*KeyboardInterrupt*'])
 
     def test_keyboard_in_sessionstart(self, testdir):
@@ -268,7 +274,7 @@ class TestCollectonly:
         p = testdir.makepyfile("import Errlkjqweqwe")
         result = testdir.runpytest("--collect-only", p)
         assert result.ret == 1
-        result.stdout.fnmatch_lines(py.code.Source("""
+        result.stdout.fnmatch_lines(_pytest._code.Source("""
             *ERROR*
             *import Errlk*
             *ImportError*
@@ -522,18 +528,70 @@ def test_fail_reporting_on_pass(testdir):
     result = testdir.runpytest('-rf')
     assert 'short test summary' not in result.stdout.str()
 
+def test_pass_extra_reporting(testdir):
+    testdir.makepyfile("def test_this(): assert 1")
+    result = testdir.runpytest()
+    assert 'short test summary' not in result.stdout.str()
+    result = testdir.runpytest('-rp')
+    result.stdout.fnmatch_lines([
+        "*test summary*",
+        "PASS*test_pass_extra_reporting*",
+    ])
+
+def test_pass_reporting_on_fail(testdir):
+    testdir.makepyfile("def test_this(): assert 0")
+    result = testdir.runpytest('-rp')
+    assert 'short test summary' not in result.stdout.str()
+
+def test_pass_output_reporting(testdir):
+    testdir.makepyfile("""
+        def test_pass_output():
+            print("Four score and seven years ago...")
+    """)
+    result = testdir.runpytest()
+    assert 'Four score and seven years ago...' not in result.stdout.str()
+    result = testdir.runpytest('-rP')
+    result.stdout.fnmatch_lines([
+        "Four score and seven years ago...",
+    ])
+
 def test_color_yes(testdir):
     testdir.makepyfile("def test_this(): assert 1")
     result = testdir.runpytest('--color=yes')
     assert 'test session starts' in result.stdout.str()
     assert '\x1b[1m' in result.stdout.str()
 
+
 def test_color_no(testdir):
     testdir.makepyfile("def test_this(): assert 1")
     result = testdir.runpytest('--color=no')
     assert 'test session starts' in result.stdout.str()
     assert '\x1b[1m' not in result.stdout.str()
 
+
+@pytest.mark.parametrize('verbose', [True, False])
+def test_color_yes_collection_on_non_atty(testdir, verbose):
+    """skip collect progress report when working on non-terminals.
+    #1397
+    """
+    testdir.makepyfile("""
+        import pytest
+        @pytest.mark.parametrize('i', range(10))
+        def test_this(i):
+            assert 1
+    """)
+    args = ['--color=yes']
+    if verbose:
+        args.append('-vv')
+    result = testdir.runpytest(*args)
+    assert 'test session starts' in result.stdout.str()
+    assert '\x1b[1m' in result.stdout.str()
+    assert 'collecting 10 items' not in result.stdout.str()
+    if verbose:
+        assert 'collecting ...' in result.stdout.str()
+    assert 'collected 10 items' in result.stdout.str()
+
+
 def test_getreportopt():
     class config:
         class option:
